@@ -49,15 +49,15 @@ class WPScanPlugin(PluginJsonFormat):
     and adds the information to Faraday.
     """
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *arg, **kwargs):
+        super().__init__(*arg, **kwargs)
         self.id = "wpscan"
         self.name = "WPscan"
         self.plugin_version = "0.2"
         self.version = "3.4.5"
         self.json_keys = {"target_url", "effective_url", "interesting_findings"}
 
-    def parseOutputString(self, output, debug=False):
+    def parseOutputString(self, output):
         parser = WPScanJsonParser(output)
         url_data = parser.parse_url(parser.json_data['target_url'])
         host_id = self.createAndAddHost(url_data['address'], hostnames=[url_data['hostname']])
@@ -91,5 +91,5 @@ class WPScanPlugin(PluginJsonFormat):
                                               severity='unclassified')
 
 
-def createPlugin():
-    return WPScanPlugin()
+def createPlugin(ignore_info=False):
+    return WPScanPlugin(ignore_info=ignore_info)
